@@ -222,7 +222,12 @@ def serve(
                     titleRefs=title_refs,
                     side=sidebar,
                     nav={"links": [
-                        {"title": "Github", "url": "https://github.com/hapticx/hapdoc"},
+                        {
+                            "title": "Github",
+                            "icon": "fab fa-github",
+                            "show_text": True,
+                            "url": "https://github.com/hapticx/hapdoc"
+                        },
                     ]},
                     accentColor=accent_color,
                     backgroundColor=background_color,
@@ -340,8 +345,8 @@ def build(
                     nav={"links": [
                         {
                             "title": "Github",
-                            "icon": "fa-brands fa-github",
-                            "show_text": False,
+                            "icon": "fab fa-github",
+                            "show_text": True,
                             "url": "https://github.com/hapticx/hapdoc"
                         },
                     ]},
